
# Slot: is frameshift variant of


holds between a sequence variant and a gene, such the sequence variant causes a disruption of the translational reading frame, because the number of nucleotides inserted or deleted is not a multiple of three.

URI: [biolink:is_frameshift_variant_of](https://w3id.org/biolink/vocab/is_frameshift_variant_of)


## Domain and Range

[SequenceVariant](SequenceVariant.md) &#8594;  <sub>0..\*</sub> [Gene](Gene.md)

## Parents

 *  is_a: [is sequence variant of](is_sequence_variant_of.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | SO:0001589 |
|  | | SNPEFF:frameshift_variant |
| **Narrow Mappings:** | | SNPEFF:start_lost |
|  | | SNPEFF:stop_lost |

